@@ -1,5 +1,5 @@
 /*  GNU SED, a batch stream editor.
-    Copyright (C) 1989-2017 Free Software Foundation, Inc.
+    Copyright (C) 1989-2018 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,16 +37,6 @@
 #include "acl.h"
 #include "ignore-value.h"
 
-#ifdef __GNUC__
-# if __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__-0 >= 7)
-   /* silence warning about unused parameter even for "gcc -W -Wunused" */
-#  define UNUSED	__attribute__((unused))
-# endif
-#endif
-#ifndef UNUSED
-# define UNUSED
-#endif
-
 /* The number of extra bytes that must be allocated/usable, beyond
    the declared "end" of each line buffer that may be passed to
    match_regex.  This is imposed by its use of dfaexec.  */
@@ -386,7 +376,7 @@ line_exchange (struct line *a, struct line *b, int state)
 
 /* dummy function to simplify read_pattern_space() */
 static bool
-read_always_fail(struct input *input UNUSED)
+read_always_fail(struct input *input _GL_UNUSED)
 {
   return false;
 }
@@ -607,7 +597,7 @@ open_next_file(const char *name, struct input *input)
       if (is_selinux_enabled () > 0)
         {
           security_context_t con;
-          if (getfilecon (input->in_file_name, &con) != -1)
+          if (lgetfilecon (input->in_file_name, &con) != -1)
             {
               /* Save and restore the old context for the sake of w and W
                  commands.  */
@@ -1324,7 +1314,7 @@ execute_program(struct vector *vec, struct input *input)
                             &output_file);
               /* POSIX.2 is silent about c starting a new cycle,
                  but it seems to be expected (and make sense). */
-              /* Fall Through */
+              FALLTHROUGH;
             case 'd':
               return -1;
 
@@ -1480,7 +1470,7 @@ execute_program(struct vector *vec, struct input *input)
                 output_line(line.active, line.length, line.chomped,
                             &output_file);
               dump_append_queue();
-              /* FALLTHROUGH */
+              FALLTHROUGH;
 
             case 'Q':
               return cur_cmd->x.int_arg == -1 ? 0 : cur_cmd->x.int_arg;
