@@ -1,5 +1,5 @@
 /*  GNU SED, a batch stream editor.
-    Copyright (C) 1989-2017 Free Software Foundation, Inc.
+    Copyright (C) 1989-2018 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -110,8 +110,8 @@ contact(int errmsg)
 {
   FILE *out = errmsg ? stderr : stdout;
 #ifndef REG_PERL
-  fprintf(out, _("GNU sed home page: <http://www.gnu.org/software/sed/>.\n\
-General help using GNU software: <http://www.gnu.org/gethelp/>.\n"));
+  fprintf(out, _("GNU sed home page: <https://www.gnu.org/software/sed/>.\n\
+General help using GNU software: <https://www.gnu.org/gethelp/>.\n"));
 #endif
 
   /* Only print the bug report address for `sed --help', otherwise we'll
@@ -168,7 +168,7 @@ Usage: %s [OPTION]... {script-only-if-no-other-script} [input-file]...\n\
                  consider files as separate rather than as a single,\n\
                  continuous long stream.\n"));
   fprintf(out, _("      --sandbox\n\
-                 operate in sandbox mode.\n"));
+                 operate in sandbox mode (disable e/r/w commands).\n"));
   fprintf(out, _("  -u, --unbuffered\n\
                  load minimal amounts of data from the input files and flush\n\
                  the output buffers more often\n"));
